# SLIP-0044 : Registered coin types for BIP-0044

```
Number:  SLIP-0044
Title:   Registered coin types for BIP-0044
Type:    Standard
Status:  Draft
Authors: Pavol Rusnak <stick@satoshilabs.com>
         Marek Palatinus <slush@satoshilabs.com>
Created: 2014-07-09
```

## Abstract

BIP-0044 defines a logical hierarchy for deterministic wallets.
Level 2 of the hierarchy describes a coin type in use.

## Motivation

BIP repository does not want to deal with assigning the values for various
coin types different than Bitcoin so we propose this SLIP to become such body.

## Registered coin types

These are the registered coin types for usage in level 2 of BIP44 described in chapter "Coin type".

All these constants are used as hardened derivation.

index | hexa       | symbol | coin
------|------------|--------|-----------------------------------
0     | 0x80000000 | BTC    | [Bitcoin](https://bitcoin.org/)
1     | 0x80000001 |        | Testnet (all coins)
2     | 0x80000002 | LTC    | [Litecoin](https://litecoin.org/)
3     | 0x80000003 | DOGE   | [Dogecoin](https://github.com/dogecoin/dogecoin)
4     | 0x80000004 | RDD    | Reddcoin
5     | 0x80000005 | DSH    | [Dash](https://github.com/dashpay/dash) (ex Darkcoin)
6     | 0x80000006 | PPC    | [Peercoin](https://peercoin.net/)
7     | 0x80000007 | NMC    | [Namecoin](http://namecoin.info/)
8     | 0x80000008 | FTC    | [Feathercoin](https://www.feathercoin.com/)
9     | 0x80000009 | XCP    | [Counterparty](http://counterparty.io/)
10    | 0x8000000a | BLK    | [Blackcoin](http://blackcoin.co/)
11    | 0x8000000b | NSR    | [NuShares](https://nubits.com/nushares/introduction)
12    | 0x8000000c | NBT    | NuBits
13    | 0x8000000d | MZC    | Mazacoin
14    | 0x8000000e | VIA    | Viacoin
15    | 0x8000000f | XCH    | ClearingHouse
16    | 0x80000010 | RBY    | Rubycoin
17    | 0x80000011 | GRS    | Groestlcoin
18    | 0x80000012 | DGC    | Digitalcoin
19    | 0x80000013 | CCN    | Cannacoin
20    | 0x80000014 | DGB    | DigiByte
21    | 0x80000015 |        | [Open Assets](https://github.com/OpenAssets/open-assets-protocol)
22    | 0x80000016 | MONA   | Monacoin
23    | 0x80000017 | CLAM   | Clams
24    | 0x80000018 | XPM    | Primecoin
25    | 0x80000019 | NEOS   | Neoscoin
26    | 0x8000001a | JBS    | Jumbucks
27    | 0x8000001b | ZRC    | ziftrCOIN
28    | 0x8000001c | VTC    | Vertcoin
29    | 0x8000001d | NXT    | NXT
30    | 0x8000001e | BURST  | Burst
31    | 0x8000001f | MUE    | MonetaryUnit
32    | 0x80000020 | ZOOM   | Zoom
33    | 0x80000021 | VASH   | [Virtual Cash](http://www.bitnet.cc/) Also known as VPNcoin
34    | 0x80000022 | CDN    | [Canada eCoin](https://github.com/Canada-eCoin/)
35    | 0x80000023 | SDC    | ShadowCash
36    | 0x80000024 | PKB    | [ParkByte](https://github.com/parkbyte/)
37    | 0x80000025 | PND    | Pandacoin
38    | 0x80000026 | START  | StartCOIN
39    | 0x80000027 | MOIN   | [MOIN](https://discovermoin.com)
40    | 0x80000028 | EXP    | [Expanse](http://www.expanse.tech/)
41    | 0x80000029 | EMC2   | [Einsteinium](https://www.emc2.foundation/)
42    | 0x8000002a | DCR    | [Decred](https://decred.org/)
43    | 0x8000002b | XEM    | [NEM](https://github.com/NemProject)
44    | 0x8000002c | PART   | [Particl](https://particl.io/)
45    | 0x8000002d | ARG    | [Argentum](http://www.argentum.io)
46    | 0x8000002e |        | [Libertas](https://github.com/dangershony/Libertas)
47    | 0x8000002f |        | [Posw coin](https://poswallet.com)
48    | 0x80000030 | SHR    | [Shreeji](https://github.com/SMJBIT/SHREEJI)
49    | 0x80000031 | GCR    | Global Currency Reserve (GCRcoin)
50    | 0x80000032 | NVC    | [Novacoin](https://github.com/novacoin-project/novacoin)
51    | 0x80000033 | AC     | [Asiacoin](https://github.com/AsiaCoin/AsiaCoinFix)
52    | 0x80000034 | BTCD   | [Bitcoindark](https://github.com/jl777/btcd)
53    | 0x80000035 | DOPE   | [Dopecoin](https://github.com/dopecoin-dev/DopeCoinV3)
54    | 0x80000036 | TPC    | [Templecoin](https://github.com/9cat/templecoin)
55    | 0x80000037 | AIB    | [AIB](https://github.com/iobond/aib)
56    | 0x80000038 | EDRC   | [EDRCoin](https://github.com/EDRCoin/EDRcoin-src)
57    | 0x80000039 | SYS    | [Syscoin](https://github.com/syscoin/syscoin2)
58    | 0x8000003a | SLR    | [Solarcoin](https://github.com/onsightit/solarcoin)
59    | 0x8000003b | SMLY   | [Smileycoin](https://github.com/tutor-web/smileyCoin)
60    | 0x8000003c | ETH    | [Ether](https://ethereum.org/ether)
61    | 0x8000003d | ETC    | [Ether Classic](https://ethereumclassic.github.io)
62    | 0x8000003e | PSB    | [Pesobit](https://github.com/pesobitph/pesobit-source)
63    | 0x8000003f | LDCN   | [Landcoin](http://landcoin.co/)
64    | 0x80000040 |        | [Open Chain](https://github.com/openchain/)
65    | 0x80000041 | XBC    | [Bitcoinplus](https://bitcoinplus.org)
66    | 0x80000042 | IOP    | [Internet of People](http://www.fermat.org)
67    | 0x80000043 | NXS    | [Nexus](http://www.nexusearth.com/)
68    | 0x80000044 | INSN   | [InsaneCoin](http://insanecoin.com)
69    | 0x80000045 | OK     | [OKCash](https://github.com/okcashpro/)
70    | 0x80000046 | BRIT   | [BritCoin](https://britcoin.com)
71    | 0x80000047 | CMP    | [Compcoin](https://compcoin.com)
72    | 0x80000048 | CRW    | [Crown](http://crown.tech/)
73    | 0x80000049 | BELA   | [BelaCoin](http://belacoin.org)
74    | 0x8000004a |        |
75    | 0x8000004b | FJC    | [FujiCoin](http://www.fujicoin.org/)
76    | 0x8000004c | MIX    | [MIX](https://www.mix-blockchain.org/)
77    | 0x8000004d | XVG    | [Verge](https://github.com/vergecurrency/verge/)
78    | 0x8000004e | EFL    | [Electronic Gulden](https://egulden.org/)
79    | 0x8000004f | CLUB   | [ClubCoin](https://clubcoin.co/)
80    | 0x80000050 | RICHX  | [RichCoin](https://richcoin.us/)
81    | 0x80000051 | POT    | [Potcoin](http://potcoin.com/)
82    | 0x80000052 | QRK    | Quarkcoin
83    | 0x80000053 | TRC    | Terracoin
84    | 0x80000054 | GRC    | Gridcoin
85    | 0x80000055 | AUR    | [Auroracoin](http://auroracoin.is/)
86    | 0x80000056 | IXC    | IXCoin
87    | 0x80000057 | NLG    | [Gulden](https://Gulden.com/)
88    | 0x80000058 | BITB   | [BitBean](http://bitbean.org/)
89    | 0x80000059 | BTA    | [Bata](http://bata.io/)
90    | 0x8000005a | XMY    | [Myriadcoin](http://myriadcoin.org)
91    | 0x8000005b | BSD    | [BitSend](http://bitsend.info)
92    | 0x8000005c | UNO    | [Unobtanium](http://http://unobtanium.uno/)
93    | 0x8000005d | MTR    | [MasterTrader](https://github.com/CrypticApplications/MTR-Update/)
94    | 0x8000005e | GB     | [GoldBlocks](https://github.com/goldblockscoin/goldblocks)
95    | 0x8000005f | SHM    | [Saham](https://github.com/SahamDev/SahamDev)
96    | 0x80000060 | CRX    | [Chronos](https://github.com/chronoscoin/Chronoscoin)
97    | 0x80000061 | BIQ    | [Ubiquoin](https://github.com/ubiquoin/ubiq)
98    | 0x80000062 | EVO    | [Evotion](https://github.com/evoshiun/Evotion)
99    | 0x80000063 | STO    | [SaveTheOcean](https://github.com/SaveTheOceanMovement/SaveTheOceanCoin)
100   | 0x80000064 | BIGUP  | [BigUp](https://github.com/BigUps/)
101   | 0x80000065 | GAME   | [GameCredits](https://github.com/gamecredits-project)
102   | 0x80000066 | DLC    | [Dollarcoins](https://github.com/dollarcoins/source)
103   | 0x80000067 | ZYD    | [Zayedcoin](https://github.com/ZayedCoin/Zayedcoin)
104   | 0x80000068 | DBIC   | [Dubaicoin](https://github.com/DubaiCoinDev/DubaiCoin)
105   | 0x80000069 | STRAT  | [Stratis](http://www.stratisplatform.com)
106   | 0x8000006a | SH     | [Shilling](https://github.com/yavwa/Shilling)
107   | 0x8000006b | MARS   | [MarsCoin](http://www.marscoin.org/)
108   | 0x8000006c | UBQ    | [Ubiq](https://github.com/Ubiq)
109   | 0x8000006d | PTC    | [Pesetacoin](http://pesetacoin.info/)
110   | 0x8000006e | NRO    | [Neurocoin](https://neurocoin.org)
111   | 0x8000006f | ARK    | [ARK](https://ark.io)
112   | 0x80000070 | USC    | [UltimateSecureCashMain](http://ultimatesecurecash.info)
113   | 0x80000071 | THC    | [Hempcoin](http://hempcoin.org)
114   | 0x80000072 | LINX   | [Linx](https://mylinx.io)
115   | 0x80000073 | ECN    | [Ecoin](https://www.ecoinsource.com)
116   | 0x80000074 | DNR    | [Denarius](https://denarius.io)
117   | 0x80000075 | PINK   | [Pinkcoin](http://getstarted.with.pink)
118   | 0x80000076 | PIGGY  | [PiggyCoin](https://www.piggy-coin.com/)
119   | 0x80000077 | PIVX   | [Pivx](https://github.com/PIVX-Project/PIVX)
120   | 0x80000078 | FLASH  | [Flashcoin](https://flashcoin.io)
121   | 0x80000079 | ZEN    | [Zencash](https://zensystem.io)
122   | 0x8000007a | PUT    | [Putincoin](https://putincoin.info)
123   | 0x8000007b | ZNY    | [BitZeny](http://bitzeny.org/)
124   | 0x8000007c | UNIFY  | [Unify](http://unifycryptocurrency.com)
125   | 0x8000007d | XST    | [StealthCoin](http://www.stealthcoin.com)
126   | 0x8000007e | BRK    | [Breakout Coin](http://www.breakoutcoin.com)
127   | 0x8000007f | VC     | [Vcash](https://vcash.info)
128   | 0x80000080 | XMR    | [Monero](https://getmonero.org/)
129   | 0x80000081 | VOX    | [Voxels](https://www.voxelus.com)
130   | 0x80000082 | NAV    | [NavCoin](https://github.com/navcoindev/navcoin2)
131   | 0x80000083 | FCT    | [Factom Factoids](https://github.com/FactomProject/FactomDocs/blob/master/wallet_info/wallet_test_vectors.md)
132   | 0x80000084 | EC     | [Factom Entry Credits](https://github.com/FactomProject)
133   | 0x80000085 | ZEC    | [Zcash](https://z.cash)
134   | 0x80000086 | LSK    | [Lisk](https://lisk.io/)
135   | 0x80000087 | STEEM  | [Steem](http://steem.io)
136   | 0x80000088 | XZC    | [ZCoin](https://zcoin.io)
137   | 0x80000089 | SBTC   | [RSK](http://www.rsk.co/)
138   | 0x8000008a |        | [Giftblock](https://github.com/gyft/giftblock)
139   | 0x8000008b | RPT    | [RealPointCoin](https://github.com/MaxSmile/RealPointCoinQt)
140   | 0x8000008c | LBC    | [LBRY Credits](https://lbry.io/)
141   | 0x8000008d | KMD    | [Komodo](https://komodoplatform.com/)
142   | 0x8000008e | BSQ    | [bisq Token](http://bisq.io/)
143   | 0x8000008f | RIC    | [Riecoin](https://github.com/riecoin/riecoin)
144   | 0x80000090 | XRP    | [Ripple](https://ripple.com)
145   | 0x80000091 | BCH    | [Bitcoin Cash](https://www.bitcoincash.org)
146   | 0x80000092 | NEBL   | [Neblio](https://nebl.io)
147   | 0x80000093 | ZCL    | [ZClassic](http://zclassic.org/)
148   | 0x80000094 | XLM    | [Stellar Lumens](https://www.stellar.org/)
149   | 0x80000095 | NLC2   | [NoLimitCoin2](http://www.nolimitcoin.org)
150   | 0x80000096 | WHL    | [WhaleCoin](https://whalecoin.org/)
151   | 0x80000097 | ERC    | [EuropeCoin](https://www.europecoin.eu.org/)
152   | 0x80000098 | DMD    | [Diamond](http://bit.diamonds)
153   | 0x80000099 | BTM    | [Bytom](https://bytom.io)
154   | 0x8000009a | BIO    | [Biocoin](https://biocoin.bio)
155   | 0x8000009b | XWC    | [Whitecoin](https://www.whitecoin.info)
156   | 0x8000009c | BTG    | [Bitcoin Gold](http://www.btcgpu.org)
157   | 0x8000009d | BTC2X  | [Bitcoin 2x](https://medium.com/@DCGco/bitcoin-scaling-agreement-at-consensus-2017-133521fe9a77)
158   | 0x8000009e | SSN    | [SuperSkynet](http://wwww.superskynet.org/)
159   | 0x8000009f | TOA    | [TOACoin](http://www.toacoin.com)
160   | 0x800000a0 | BTX    | [Bitcore](https://bitcore.cc)
161   | 0x800000a1 | ACC    | [Adcoin](https://www.getadcoin.com/)
162   | 0x800000a2 | BCO    | [Bridgecoin](https://bridgecoin.org/)
163   | 0x800000a3 | ELLA   | [Ellaism](https://ellaism.org)
164   | 0x800000a4 | PIRL   | [Pirl](https://pirl.io)
165   | 0x800000a5 | XRB    | [RaiBlocks](https://raiblocks.com)
166   | 0x800000a6 | VIVO   | [Vivo](https://www.vivocrypto.com/)
167   | 0x800000a7 | FRST   | [Firstcoin](http://firstcoinproject.com)
168   | 0x800000a8 | HNC    | [Helleniccoin](http://www.helleniccoin.gr/)
169   | 0x800000a9 | BUZZ   | [BUZZ](http://www.buzzcoin.info/)
170   | 0x800000aa | MBRS   | [Ember](https://www.embercoin.io/)
171   | 0x800000ab | HSR    | [Hcash](https://h.cash)
172   | 0x800000ac | HTML   | [HTMLCOIN](https://htmlcoin.com/)
173   | 0x800000ad | ODN    | [Obsidian](https://obsidianplatform.com/)
174   | 0x800000ae | ONX    | [OnixCoin](https://www.onixcoin.com/)
175   | 0x800000af | RVN    | [Ravencoin](https://ravencoin.org/)
176   | 0x800000b0 | GBX    | [GoByte](https://gobyte.network)
177   | 0x800000b1 | BTCZ   | [BitcoinZ](https://btcz.rocks/en/)
178   | 0x800000b2 | POA    | [Poa](https://poa.network)
179   | 0x800000b3 | NYC    | [NewYorkCoin](http://nycoin.net)
180   | 0x800000b4 | MXT    | [MarteXcoin](http://martexcoin.org)
181   | 0x800000b5 | WC     | [Wincoin](https://wincoin.co)
182   | 0x800000b6 | MNX    | [Minexcoin](https://minexcoin.com)
183   | 0x800000b7 | BTCP   | [Bitcoin Private](https://btcprivate.org)
184   | 0x800000b8 | MUSIC  | [Musicoin](https://www.musicoin.org)
185   | 0x800000b9 | BCA    | [Bitcoin Atom](https://bitcoinatom.io)
186   | 0x800000ba | CRAVE  | [Crave](https://craveproject.net)
187   | 0x800000bb | STAK   | [STRAKS](https://straks.io)
188   | 0x800000bc | WBTC   | [World Bitcoin](http://www.wbtcteam.org/)
189   | 0x800000bd | LCH    | [LiteCash](http://www.litecash.info/)
190   | 0x800000be | EXCL   | [ExclusiveCoin](https://exclusivecoin.pw/)
191   | 0x800000bf |        | [Lynx](https://getlynx.io)
192   | 0x800000c0 | LCC    | [LitecoinCash](https://litecoinca.sh)
193   | 0x800000c1 | XFE    | [Feirm](https://www.feirm.com)
194   | 0x800000c2 | EOS    | [EOS](https://eos.io)
195   | 0x800000c3 | TRX    | [Tron](https://tron.network/enindex.html)
196   | 0x800000c4 | KOBO   | [Kobocoin](https://kobocoin.com)
197   | 0x800000c5 | HUSH   | [HUSH](https://myhush.org)
198   | 0x800000c6 | BANANO | [Bananos](https://banano.co.in)
199   | 0x800000c7 | ETF    | [ETF](http://ethereumfog.org)
200   | 0x800000c8 | OMNI   | [Omni](http://www.omnilayer.org)
201   | 0x800000c9 | BIFI   | [BitcoinFile](https://www.bitcoinfile.org)
202   | 0x800000ca | UFO    | [Uniform Fiscal Object](https://ufobject.com)
203   | 0x800000cb | CNMC   | [Cryptonodes](https://www.cryptonodes.ch)
204   | 0x800000cc | NRG    | [Energi](https://www.energi.world)
205   | 0x800000cd | RIN    | [Ringo](http://dkwzjw.github.io/ringo/)
206   | 0x800000ce | ATP    | [PlatON](https://www.platon.network)
207   | 0x800000cf | EVT    | [everiToken](https://everiToken.io)
208   | 0x800000d0 | ATN    | [ATN](https://atn.io)
209   | 0x800000d1 | BIS    | [Bismuth](http://www.bismuth.cz)
210   | 0x800000d2 | NEET   | [NEETCOIN](https://neetcoin.jp/)
211   | 0x800000d3 | BOPO   | [BopoChain](http://www.bopochain.org/)
215   | 0x800000d7 | BOXY   | [BoxyCoin](http://www.boxycoin.org/)
216   | 0x800000d8 | FLO    | [Flo](https://www.flo.cash/)
222   | 0x800000de | BITG   | [Bitcoin Green](https://savebitcoin.io)
223   | 0x800000df | ASK    | [AskCoin](https://askcoin.org)
224   | 0x800000e0 | SMART  | [Smartcash](https://smartcash.cc)
225   | 0x800000e1 | XUEZ   | [XUEZ](https://xuezcoin.com)
226   | 0x800000e2 | HLM    | [Helium](https://www.heliumlabs.org/)
233   | 0x800000e9 | VAR    | [Varda](https://varda.io)
242   | 0x800000f2 | NIM    | [Nimiq](https://nimiq.com/)
247   | 0x800000f7 | UC     | [Ulord](http://ulord.one)
255   | 0x800000ff |        | [SmartHoldem](https://smartholdem.io)
256   | 0x80000100 | NANO   | [Bitcoin Nano](https://www.btcnano.org)
258   | 0x80000102 |        | [Zen Protocol](https://www.zenprotocol.com/)
259   | 0x80000103 | ZEST   | [Zest](https://www.zestcoin.io)
270   | 0x8000010e | ONE    | [ONE](http://www.onechain.one/)
271   | 0x8000010f | SBC    | [SBC](http://www.smartbitcoin.one)
299   | 0x8000012b | NUKO   | [Nekonium](https://nekonium.github.io/)
300   | 0x8000012c | GNX    | [Genaro Network](https://genaro.network/)
312   | 0x80000138 | ARA    | [Aura](https://auraledger.com/)
321   | 0x80000141 | RAP    | [Rapture](https://our-rapture.com/)
328   | 0x80000148 | BLOCK  | [Blocknet](https://blocknet.co/)
333   | 0x8000014d | MEM    | [MemCoin](https://memcoin.org)
425   | 0x800001a9 | AION   | [Aion](https://aion.network)
444   | 0x800001bc | PHR    | [Phore](https://phore.io)
510   | 0x800001fe | KOTO   | [Koto](https://ko-to.org/)
512   | 0x80000200 | XRD    | [Radiant](https://radiant.cash/)
528   | 0x80000210 | YAP    | [Yapstone](https://yapstone.pro/)
555   | 0x8000022b | BCS    | [Bitcoin Smart](http://bcs.info)
625   | 0x80000271 | EAST   | [Eastcoin](http://easthub.io/)
666   | 0x8000029a | ACT    | [Achain](https://www.achain.com/)
668   | 0x8000029c | SSC    | [SelfSell](https://www.selfsell.com/)
777   | 0x80000309 | BTW    | [Bitcoin World](http://btw.one)
800   | 0x80000320 | BEET   | [Beetle Coin](https://beetlecoin.io/)
808   | 0x80000328 | QVT    | [Qvolta](https://qvolta.com)
818   | 0x80000332 | VET    | [VeChain Token](https://vechain.com/)
820   | 0x80000334 | CLO    | [Callisto](http://callisto.network/)
886   | 0x80000376 | ADF    | [AD Token](http://adfunds.org)
888   | 0x80000378 | NEO    | [NEO](https://neo.org/)
890   | 0x8000037a | XSEL   | [Seln](https://selnx.jp/)
998   | 0x800003e6 | LBTC   | [Lightning Bitcoin](http://lbtc.io/)
999   | 0x800003e7 | BCD    | [Bitcoin Diamond](http://btcd.io/)
1000  | 0x800003e8 | BTN    | [Bitcoin New](http://bitcoinnew.org/)
1024  | 0x80000400 | ONT    | [Ontology](https://ont.io)
1111  | 0x80000457 | BBC    | [Big Bitcoin](http://bigbitcoins.org/)
1122  | 0x80000462 | CMT    | [CyberMiles Token](https://www.cybermiles.io)
1128  | 0x80000468 | ETSC   | [Ethereum Social](https://ethereumsocial.kr/)
1145  | 0x80000479 | CDY    | [Bitcoin Candy](http://www.bitcoincandy.one)
1337  | 0x80000539 | DFC    | [Defcoin](http://defcoin-ng.org)
1397  | 0x80000575 | HYC    | [Hycon](https://hycon.io)
1524  | 0x800005f4 |        | [Taler](http://taler.site)
1688  | 0x80000698 | BCX    | [BitcoinX](https://bcx.org)
1729  | 0x800006c1 | XTZ    | [Tezos](https://tezos.com)
1815  | 0x80000717 | ADA    | [Cardano](https://www.cardanohub.org/en/home/)
1856  | 0x80000743 | TES    | [Teslacoin](https://www.tesla-coin.com/)
1901  | 0x8000076d | CLC    | [Classica](https://github.com/classica/)
1919  | 0x8000077f | VIPS   | [VIPSTARCOIN](https://www.vipstarcoin.jp/)
1977  | 0x800007b9 | XMX    | [Xuma](http://www.xumacoin.org/)
1987  | 0x800007c3 | EGEM   | [EtherGem](https://egem.io)
1989  | 0x800007c5 | HODL   | [HOdlcoin](https://hodlcoin.com/)
1997  | 0x800007cd | POLIS  | [Polis](https://polispay.org/)
2018  | 0x800007e2 | EOSC   | [EOSClassic](https://eos-classic.io/)
2301  | 0x800008fd | QTUM   | [QTUM](https://qtum.org/en/)
2302  | 0x800008fe | ETP    | [Metaverse](https://mvs.org/)
2303  | 0x800008ff | GSX    | [GXChain](https://www.gxb.io)
3552  | 0x80000de0 | DEO    | [Destocoin](https://desto.io)
2718  | 0x80000a9e | NAS    | [Nebulas](https://nebulas.io/)
3377  | 0x80000d31 | ROI    | [ROIcoin](https://roi-coin.com/)
4218  | 0x8000107a | IOTA   | [IOTA](https://www.iota.org/)
4242  | 0x80001092 | AXE    | [Axe](https://github.com/AXErunners/axe)
5248  | 0x00001480 | FIC    | [FIC](https://ficnetwork.com)
5757  | 0x8000167d |        | [Stacks](https://github.com/blockstack/blockstack-core)
6060  | 0x800017ac | GO     | [GoChain GO](https://gochain.io/)
6666  | 0x80001a0a | BPA    | [Bitcoin Pizza](http://p.top/)
6688  | 0x80001a20 | SAFE   | [SAFE](http://www.anwang.com/)
6969  | 0x80001b39 | ROGER  | [TheHolyrogerCoin](https://github.com/TheHolyRoger/TheHolyRogerCoin)
7777  | 0x80001e61 | BTV    | [Bitvote](https://www.bitvote.one)
8339  | 0x80002093 | BTQ    | [BitcoinQuark](https://www.bitcoinquark.org)
8888  | 0x800022b8 | SBTC   | [Super Bitcoin](https://www.superbtc.org)
8999  | 0x80002327 | BTP    | [Bitcoin Pay](http://www.btceasypay.com)
9888  | 0x800026a0 | BTF    | [Bitcoin Faith](http://bitcoinfaith.org)
9999  | 0x8000270f | GOD    | [Bitcoin God](https://www.bitcoingod.org)
22504 | 0x800057e8 | PWR    | [PWRcoin](https://github.com/Plainkoin/PWRcoin)
31102 | 0x8000797e | ESN    | [EtherSocial Network](https://ethersocial.network)
31337 | 0x80007a69 |        | [ThePower.io](https://thepower.io)
33878 | 0x80008456 | BTCS   | [Bitcoin Stake](http://www.btcscoin.com/)
37310 | 0x800091be |        | [RSK Testnet](http://www.rsk.co/)
99999 | 0x8001869f | WICC   | [Waykichain](http://www.waykichain.com)
200625 | 0x80030fb1 | AKA    | [Akroma](https://akroma.io)
1712144 | 0x801a2010 | LAX    | [LAPO](https://lapo.io)
5249353 | 0x80501949 | BCO    | [BitcoinOre](http://bitcoinore.org/)
5718350 | 0x8057414e | WAN    | [Wanchain](https://wanchain.org/)
5741564 | 0x80579bfc | WAVES  | [Waves](https://wavesplatform.com/)
91927009 | 0x857ab1e1 | kUSD   | [kUSD](https://kowala.tech)

Coin types will be added only if there is a wallet implementing BIP-0044 for desired coin.

## Libraries

* [BIP44-constants](https://www.npmjs.com/package/bip44-constants) ([source](http://github.com/bitcoinjs/bip44-constants)) JavaScript package with described coin types

## References

* [BIP-0044: Multi-Account Hierarchy for Deterministic Wallets](https://github.com/bitcoin/bips/blob/master/bip-0044.mediawiki)
