# SLIP-0173 : Registered human-readable parts for BIP-0173

```
Number:  SLIP-0173
Title:   Registered human-readable parts for BIP-0173
Type:    Standard
Status:  Draft
Authors: Clark Moody <clark@clarkmoody.com>
Created: 2017-05-17
```

## Abstract

BIP-0173 defines a new format for segregated witness output addresses that contains a human-readable part that identifies the coin type.

## Motivation

The BIP repository does not want to deal with assigning the values for various coin types different than Bitcoin so we propose this SLIP to become such body.

## Registered human-readable parts

These are the registered human-readable parts for usage in Bech32 encoding of witness programs.

| Coin                                       | Mainnet | Testnet | Regtest   |
| ------------------------------------------ | ------- | ------- | --------- |
| [Bitcoin](https://bitcoin.org/)            | `bc`    | `tb`    | `bcrt`    |
| [Bitcoin Atom](https://bitcoinatom.io/)    | `bca`   | `tbca`  | `bcart`   |
| [Bitcoin Gold](https://bitcoingold.org/)   | `btg`   | `tbtg`  |           |
| [Bitcoin Platinum](https://btcplt.org/)    | `btp`   | `tbtp`  |           |
| [Bitcoin Private](https://btcprivate.org/) | `btcp`  | `tbtcp` | `regbtcp` |
| [Bitcore](https://bitcore.cc/)             | `btx`   | `tbtx`  |           |
| [DigiByte](https://www.digibyte.io/)       | `dgb`   | `dgbt`  | `dgbrt`   |
| [FujiCoin](http://www.fujicoin.org/)       | `fc`    | `tf`    | `fcrt`    |
| [Groestlcoin](https://groestlcoin.org/)    | `grs`   | `tgrs`  |           |
| [Litecoin](https://litecoin.org/)          | `ltc`   | `tltc`  | `rltc`    |
| [Namecoin](https://www.namecoin.org/)      | `nc`    | `tn`    | `ncrt`    |
| [Ravencon](https://ravencoin.org/)         | `rc`    | `tr`    | `rcrt`    |
| [Vertcoin](https://vertcoin.org/)          | `vtc`   | `tvtc`  |           |
| [Viacoin](https://viacoin.org/)            | `via`   | `tvia`  |           |
| [Zen Protocol](https://zenprotocol.com/)   | `zen`   | `tzn`   |           |

## Libraries

* [Reference Implementations](https://github.com/sipa/bech32/tree/master/ref)

## References

* [BIP-0173: Base32 address format for native v0-16 witness outputs](https://github.com/bitcoin/bips/blob/master/bip-0173.mediawiki)
